@@ -8,6 +8,7 @@ from cloudam_stream.core.utils import base64_utils, dict_utils
 from cloudam_stream.core.constants import actor_constant, config
 from cloudam_stream.core.streams import RedisConsumer, RedisProducer
 from cloudam_stream.core.utils.actor_utils import FlowStateUtils
+from cloudam_stream.core.utils import serialize_inner
 import pickle
 import os
 
@@ -102,7 +103,7 @@ class StreamApp(object):
                         # 解析消息体
                         msg_body = msg_item[1][b'']
                         # 解析消息体json格式
-                        msg_object = pickle.loads(msg_body)
+                        msg_object = serialize_inner.decode(msg_body)
 
                         # msg_object = json.loads(msg_body)
                         consumer.ack(stream_name, msg_id)
