@@ -1,5 +1,4 @@
 from cloudam_stream.core.constants.type_constants import Types
-import pickle
 
 
 class Meta(dict):
@@ -144,12 +143,6 @@ class Message(object):
         self.__flag = flag
         self.__data_type = data_type
 
-    def serialize(self):
-        return pickle.dumps(self)
-
-    def deserialize(self):
-        return pickle.loads(self)
-
     def set_payload(self, payload: object):
         self.__payload = payload
 
@@ -162,3 +155,8 @@ class Message(object):
     def get_data_type(self):
         return self.__data_type
 
+    def set_type(self, flag):
+        self.__flag = flag
+
+    def get_flag(self):
+        return self.__flag
