@@ -1,7 +1,9 @@
 from cloudam_stream.core.ports.port import Port
 from cloudam_stream.core.payload import Message, Record
 from cloudam_stream.core.streams import RedisProducer
+from cloudam_stream.core.utils import serialize_inner
 from typing import TypeVar, Generic
+import json
 
 
 T = TypeVar("T")
@@ -22,9 +24,9 @@ class OutputPort(Generic[T], Port):
 
     def _emit(self, payload: T):
         message_object = Message(payload, "0", type(payload).__name__)
-        # 转二进制
-        msg = message_object.serialize()
-        self.producer.produce(self.channel, msg)
+        print(json.dumps(message_object.__dict__))
+        encode_msg = serialize_inner.encode(message_object)
+        self.producer.produce(self.channel, encode_msg)
 
 
 class TextOutputPort(OutputPort[str]):
